#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-9tOEGe8o8fKPHmzoLJYNM
key:                  ghcide-2.3.0.0-9tOEGe8o8fKPHmzoLJYNM
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  1f826fd24c2b34b6041d078335417894
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-9tOEGe8o8fKPHmzoLJYNM
depends:
    Diff-0.5-Lpdp6cGB4OPHlY6nud0H07 Glob-0.10.2-AuYEclzndET3WwBx88AguA
    aeson-2.2.2.0-HX3VmpxSu7MBeXlY03a2B0 array-0.5.6.0
    async-2.2.6-6oBfo7va0Nh7ISraaAL0Gg base-4.18.2.1
    base16-bytestring-1.0.2.0-AGwhh1Ev3mPCOOC4X0N9yh binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-2eph4zYoAFzHEvr0xd94hH
    co-log-core-0.3.2.6-BA3nx5gcNuiATplO11CYNb containers-0.6.7
    cryptohash-sha1-0.11.101.0-3CAmO8Hny3b1HSdOxK3bZ1
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    dependent-map-0.4.0.1-5noGL9lvauMBFR2dx5XQQC
    dependent-sum-0.7.2.0-C198ioPjPvz2r6RTZAg4cd directory-1.3.8.5
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    enummapset-0.7.3.0-FWctjVeBh48FpEeSdhil9H exceptions-0.10.7
    extra-1.7.16-9HJWsKGqeQNGNK4b68nPpp filepath-1.4.300.1
    fingertree-0.1.6.3-JrO8vhX0I5s5xo74G2fi5d
    focus-1.0.3.2-DOQzsWWk2pCydHnGwdAbq ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-9uS0Q42TNxyD8BfqwJwn8o
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-K7mmgBJffJLB35fDQs2278
    hashable-1.4.7.0-J2hh6EbI83E8iCoykKa5KL
    hie-bios-0.12.0-6tUdn1Fsgvi590kFgkPIkA
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-FCENXTmXwkbCHsjfoD9dSI
    hls-graph-2.3.0.0-6ya4aMOTgUBOHsm6cIh9H
    hls-plugin-api-2.3.0.0-2cVMP2AJp9EB89sXuyaAt3
    implicit-hie-0.1.4.0-1bhWDk8JKkfKTSOcvAXtT7
    implicit-hie-cradle-0.5.0.1-GT1iDkxDhGTADAt4hmhowz
    lens-5.3.4-1IL9mxUdyyZ2Td3b3fp10G
    list-t-1.0.5.7-FOetqnvB3GALSg92Lvnz0c
    lsp-2.2.0.0-62EvDy2Nc6JD5v5vZC9bSk
    lsp-types-2.0.2.0-2flfgFvwnWPAWn5iHER2lx mtl-2.3.1
    opentelemetry-0.8.0-HukdAwz78Sc3I2wQhv4juD
    optparse-applicative-0.18.1.0-2Hiadv6BpzgDgx5QxnTvo5
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-1xxpbQWBfCkKy2RpQWmuRC
    prettyprinter-ansi-terminal-1.1.4-GGItlmiu8UCFEJf6nVTmBY
    random-1.2.1.3-5RWjRNGMcAI4pn7QxDBoxf
    regex-tdfa-1.3.2.5-H8j3gUuup0uJLVNboVGbR5
    row-types-1.0.1.2-4t1oGU6lVRSIw9AnA66uBt
    safe-exceptions-0.1.7.4-E8bKL7uaaVw8oJ8z17Leck
    sorted-list-0.2.3.1-7cafC68p20S9YCdi7hF1Xg
    sqlite-simple-0.4.19.0-6CU2daHMT0O8cZviSdsvd2 stm-2.5.1.0
    stm-containers-1.2.1.1-31MDOJ1woDiKuVHUN5yw9N
    syb-0.7.3-IWvKvWWONKwAx7053zcTAl text-2.0.2
    text-rope-0.3-Et3zzhmV9C052PCXSjs9WW time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-3G7k8azuVYgEaJyxfwlJrh
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-F8uKhGV3AlWbjcYkQjkcw
    vector-0.13.2.0-DMZHGTdGAnaIWH7Z4Bo5hL

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

